pub struct GitAdapter { /* private fields */ }Expand description
Git adapter implementation
Implementations
Sourceimpl GitAdapter
impl GitAdapter
Sourcepub fn open(config: GitAdapterConfig) -> Result<Self, ScmError>
pub fn open(config: GitAdapterConfig) -> Result<Self, ScmError>
Open a Git repository at the given path or current directory
Errors
Returns ScmError if the repository cannot be discovered or opened
Sourcepub fn repository(&self) -> Arc<Mutex<Repository>>
pub fn repository(&self) -> Arc<Mutex<Repository>>
Get the underlying git2 repository